@@ -1,11 +1,16 @@
-import requests
-
 from formaloo import constants, client
+from formaloo.tags import Tag
 
 
 class Activity:
 
-    def __init__(self, action, customer_data, activity_data={}, activity_date=None, tags=[]):
+    def __init__(self, action, customer_data, activity_data=None, activity_date=None, tags=None):
+        if not activity_data:
+            activity_data = {}
+
+        if not tags:
+            tags = []
+
         self.client = client.Client()
         self.action = action
         self.customer_data = customer_data
@@ -14,24 +19,24 @@ class Activity:
         self.tags = tags
 
     def create(self):
-        headers = self.client.get_headers()
         body = self.get_body()
 
-        response = requests.post(
+        response = self.client.post(
             constants.V_1_0_CREATE_ACTIVITY_ENDPOINT,
-            headers=headers,
-            data=body
+            body=body
         )
 
-        return response
+        return response.json()
 
     def get_body(self):
+        tags_body = Tag.get_list_body(self.tags)
+
         body = {
             'action': self.action,
-            'custmer': self.customer_data,
+            'customer': self.customer_data,
             'activity_data': self.activity_data,
             'activity_date': self.activity_date,
-            'tags': self.tags
+            'tags': tags_body
         }
 
         return body
