@@ -1,11 +1,19 @@
-import requests
-
 from formaloo import constants, client
+from formaloo.tags import Tag
 
 
 class Customer:
 
-    def __init__(self, base_data={}, extra_data={}, tags=[], **kwargs):
+    def __init__(self, base_data=None, extra_data=None, tags=None, **kwargs):
+        if not base_data:
+            base_data = {}
+
+        if not extra_data:
+            extra_data = {}
+
+        if not tags:
+            tags = []
+
         self.client = client.Client()
         self.base_customer_data = base_data
         self.extra_customer_data = extra_data
@@ -18,22 +26,32 @@ class Customer:
                 self.extra_customer_data[key] = value
 
     def create(self):
-        headers = self.client.get_headers()
         body = self.get_body()
 
-        response = requests.post(
+        response = self.client.post(
             constants.V_1_0_CREATE_CUSTOMER_ENDPOINT,
-            headers=headers,
-            data=body
+            body=body
         )
 
-        return response
+        return response.json()
 
     def get_body(self):
+        tags_body = Tag.get_list_body(self.tags)
+
         body = {
             'customer_data': self.extra_customer_data,
-            'tags': self.tags
+            'tags': tags_body
         }
         body.update(self.base_customer_data)
 
         return body
+
+    def get_list(self, **kwargs):
+        params = kwargs
+
+        response = self.client.get(
+            constants.V_1_0_CUSTOMERS_LIST_ENDPOINT,
+            params=params
+        )
+
+        return response.json()
